barcode

package
v0.0.0-...-056e5b0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2017 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetEllipseOverQR

func GetEllipseOverQR(camImg *cv.IplImage, qrText string) ([]cv.Point, error)

GetEllipseOverQR returns an XY coordinate located over the given QR code, if any. If the QR code is not found, nil is returned instead.

func Init

func Init()

Init initalizes the barcode resources

func QRRawData

func QRRawData(m image.Image) ([]*barcode.Symbol, error)

QRRawData returns QR data from a image. An error is returned if image can't be decoded or there is a problem with scanning the image.

Types

This section is empty.

Jump to