oor

package
v0.0.0-...-056e5b0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2017 License: MIT Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GoOOR

type GoOOR struct {
	// contains filtered or unexported fields
}

GoOOR Wrapper for C++ code in Go for object detection.

func New

func New() GoOOR

New wraps our C++ binding to a Go struct.

func (GoOOR) DetectEllipses

func (g GoOOR) DetectEllipses(img *opencv.Mat) ([]int, error)

DetectEllipses finds ellipses in the current image from a video stream. The return slice first four values are the rectangle information which surround the larges Elipses and the last two are the center of the image.

func (GoOOR) Free

func (g GoOOR) Free()

Free deletes the GoOOR object.

Jump to