Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GoOOR ¶
type GoOOR struct {
// contains filtered or unexported fields
}
GoOOR Wrapper for C++ code in Go for object detection.
func (GoOOR) DetectEllipses ¶
DetectEllipses finds ellipses in the current image from a video stream. The return slice first four values are the rectangle information which surround the larges Elipses and the last two are the center of the image.
Click to show internal directories.
Click to hide internal directories.